# The CADET-Research Data Management toolbox

Welcome to CADET-RDM, a project by the Forschungszentrum Jülich.

This tool aims to help track and version control:
- input data
- code
- software versions
- output data

and allow for easy sharing, integration, and reproduction of generated results. 

## Documentation

You can read the documentation [here](https://cadet-rdm.readthedocs.io).